@@ -242,12 +242,12 @@ class Card(ProjectItemMixIn, BaseCard):
             path = self.project.breadcrumbs(view, True)
             if self.reverse_documented_by:
                 url = '%s/%s' % (self.project.absolute_url(), 'documentation')
-                path.append( (url, self.req._('documentation')) )
+                path.append( (url, self._cw._('documentation')) )
             elif self.test_case_for:
                 path = self.test_case_for[0].breadcrumbs(view, True)
             else:
                 url = '%s/%s' % (self.project.absolute_url(), 'testcases')
-                path.append( (url, self.req._('test cases')) )
+                path.append( (url, self._cw._('test cases')) )
             path.append(self)
             return path
         return super(Card, self).breadcrumbs(view, recurs)
@@ -281,7 +281,7 @@ class File(ProjectItemMixIn, BaseFile):
             path = [self.project]
             if self.reverse_documented_by:
                 url = '%s/%s' % (self.project.absolute_url(), 'documentation')
-                label = self.req._('documentation')
+                label = self._cw._('documentation')
                 path.append( (url, label) )
             return path
         return super(File, self).breadcrumbs(view, recurs)
