@@ -9,6 +9,7 @@ __docformat__ = "restructuredtext en"
 from itertools import chain
 from datetime import datetime
 
+from cubicweb import ValidationError
 from cubicweb.server.hook import Hook, Operation
 from cubicweb.selectors import implements
 from cubicweb.server import hook
@@ -48,14 +49,16 @@ class ChangeTicketStateOnVersionStatusChange(Hook):
             for ticket in forentity.reverse_done_in:
                 if ticket.state == 'done':
                     msg = self._cw._('version published')
-                    ticket.fire_transition('ask validation',
-                                           comment=msg,
-                                           commentformat=u'text/plain')
-
+                    try:
+                        ticket.fire_transition('ask validation',
+                                               comment=msg,
+                                               commentformat=u'text/plain')
+                    except ValidationError, ex:
+                        self.error('error while trying to change ticket state after version publishing: %s', ex)
 
 class AdjustPendingTicketState(Operation):
     def precommit_event(self):
-        if (self.ticket.state == 'validation pending' and
+        if (self.ticket.state in ('done', 'validation pending') and
             (not self.ticket.done_in
              or self.ticket.done_in[0].state != 'published')):
             msg = self.session._('moved away from published version')
@@ -74,7 +77,7 @@ class ChangeTicketStateOnDoneInChange(Hook):
         asession = self._cw.actual_session()
         ticket = self._cw.entity_from_eid(self.eidfrom)
         version = self._cw.entity_from_eid(self.eidto)
-        if ticket.state == 'validation pending':
+        if ticket.state in ('done', 'validation pending'):
             AdjustPendingTicketState(self._cw, ticket=ticket)
 
 
@@ -90,11 +93,12 @@ class ResetLoadLeftOnTicketStatusChange(Hook):
         newstate = self.entity.new_state.name
         if newstate in ('done', 'rejected', 'deprecated'):
             # ticket is done, set load_left to 0
-            forentity.set_attributes(load_left=0, _cw_unsafe=True)
+            attrs = {'load_left': 0}
             if newstate in ('rejected', 'deprecated'):
                 # also reset load in that case, we don't want initial estimation
                 # to be taken into account
-                forentity.set_attributes(load=0, _cw_unsafe=True)
+                attrs['load'] = 0
+            forentity.set_attributes(_cw_unsafe=True, **attrs)
 
 
 class SetTicketLoadLeft(Hook):
@@ -104,11 +108,11 @@ class SetTicketLoadLeft(Hook):
     __select__ = Hook.__select__ & implements('Ticket',)
 
     def __call__(self):
-        # XXX use edited_attributes
-        has_load_left = 'load_left' in self.entity
-        if self.entity.load_left is None and 'load' in self.entity:
+        edited = self.entity.edited_attributes
+        has_load_left = 'load_left' in edited
+        if 'load' in edited and self.entity.load_left is None:
             self.entity.load_left = self.entity['load']
-        elif not has_load_left and 'load_left' in self.entity:
+        elif not has_load_left and 'load_left' in edited:
             # cleanup, this may cause undesired changes
             del self.entity['load_left']
 
