@@ -23,9 +23,8 @@ Local permission (granted by project):
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from yams.buildobjs import (
-    EntityType, RelationType, RelationDefinition,
-    SubjectRelation, ObjectRelation, String, Float, RichString)
+from yams.buildobjs import (EntityType, RelationDefinition,
+                            String, Float, RichString)
 
 from cubicweb.schema import (
     RQLVocabularyConstraint, RRQLExpression, ERQLExpression,
@@ -58,30 +57,59 @@ Project.add_relation(String(maxsize=256,
 Project.add_relation(String(maxsize=256,
                             description=_('url to access tarball for releases of the project')),
                      name='downloadurl')
-Project.add_relation(SubjectRelation('Project', description=_('project\'s optional dependencies')),
-                        name='recommends')
-Project.add_relation(SubjectRelation(('Card', 'File'),
-                                     constraints=[RQLVocabularyConstraint('S in_state ST, ST name "active development"')],
-                                     description=_('project\'s documentation')),
-                     name='documented_by')
-Project.add_relation(SubjectRelation('Image',
-                                    constraints=[RQLVocabularyConstraint('S in_state ST, ST name "active development"')],
-                                    description=_('project\'s screenshot')),
-                     name='screenshot')
-Project.add_relation(ObjectRelation('MailingList', cardinality='*?',
-                                    description=_("Project's related mailing list")),
-                     name='mailinglist_of')
+
 Project.get_relations('uses').next().constraints = [
     RQLVocabularyConstraint('S in_state ST, ST name "active development"') # XXX same thing for O
     ]
+
 make_workflowable(Project)
 
-class recommends(RelationType):
+
+class recommends(RelationDefinition):
     __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', RRQLExpression('U has_update_permission S', 'S'),),
         'delete': ('managers', RRQLExpression('U has_update_permission S', 'S'),),
         }
+    subject = object = 'Project'
+    description = _('project\'s optional dependencies')
+
+
+class documented_by(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    ('managers', 'staff', sexpr('developer', 'client'),),
+        'delete': ('managers', 'staff', sexpr('developer', 'client'),),
+    }
+    subject = 'Project'
+    object = ('Card', 'File')
+    constraints = [RQLVocabularyConstraint('S in_state ST, ST name "active development"')]
+    description = _('project\'s documentation')
+
+
+class screenshot(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    ('managers', 'staff', sexpr('developer', 'client'),),
+        'delete': ('managers', 'staff', sexpr('developer', 'client'),),
+    }
+    subject = 'Project'
+    object = 'Image'
+    constraints = [RQLVocabularyConstraint('S in_state ST, ST name "active development"')]
+    description = _('project\'s screenshot')
+
+
+class mailinglist_of(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    ('managers', RRQLExpression('U has_update_permission O', 'O'),),
+        'delete': ('managers', RRQLExpression('U has_update_permission O', 'O'),),
+        }
+    subject = 'MailingList'
+    object = 'Project'
+    cardinality = '*?'
+    description = _("Project's related mailing list")
+
 
 class ExtProject(EntityType):
     """project developed externally of the cubicweb forge application"""
@@ -103,11 +131,6 @@ Ticket.add_relation(Float(description=_('load for this ticket in day.man')),
 Ticket.add_relation(Float(description=_('remaining load for this ticket in day.man')),
                     name='load_left')
 
-Ticket.add_relation(SubjectRelation(('File', 'Image'),
-                                 description=_('files related to this ticket (screenshot, file needed to reproduce a bug...)')),
-                    name='attachment')
-Ticket.add_relation(ObjectRelation('Comment', cardinality='1*', composite='object'),
-                    name='comments')
 Ticket.get_relations('concerns').next().constraints = [
     RQLVocabularyConstraint('O in_state ST, ST name "active development"')
     ]
@@ -119,6 +142,20 @@ Ticket.__permissions__['update'] = ('managers', 'staff',
                                     ERQLExpression('X owned_by U, X in_state S, S name "open"'),
                                     )
 
+
+class attachment(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        # also used for Email attachment File
+        'add':    ('managers', 'staff', RRQLExpression('U has_update_permission S', 'S')),
+        'delete': ('managers', 'staff', RRQLExpression('U has_update_permission S', 'S')),
+    }
+    subject = 'Ticket'
+    object = ('File', 'Image')
+    description = _('files related to this ticket (screenshot, file needed to '
+                    'reproduce a bug...)')
+
+
 Version.add_relation(Float(description=_('computed attribute'), default=0), name='progress_target')
 Version.add_relation(Float(description=_('computed attribute'), default=0), name='progress_done')
 Version.add_relation(Float(description=_('computed attribute'), default=0), name='progress_todo')
@@ -141,9 +178,18 @@ class License(EntityType):
     shortdesc = String(required=False, fulltextindexed=True, description=_('disclaimer of the license'))
     longdesc = RichString(required=False, fulltextindexed=True, description=_("full license's text"))
     url = String(maxsize=256)
-    ## relations
-    license_of = SubjectRelation('Project', cardinality='**',
-                                 description=_("Project's license"))
+
+
+class license_of(RelationDefinition):
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    ('managers', RRQLExpression('U has_update_permission O', 'O'),),
+        'delete': ('managers', RRQLExpression('U has_update_permission O', 'O'),),
+        }
+    subject = 'License'
+    object = 'Project'
+    cardinality = '**'
+    description = _("Project's license")
 
 
 File.__permissions__ = {
@@ -200,7 +246,7 @@ class see_also(RelationDefinition):
 
 class comments(RelationDefinition):
     subject = 'Comment'
-    object = ('Card', 'File', 'Image', 'Email')
+    object = ('Ticket', 'Card', 'File', 'Image', 'Email')
     cardinality = '1*'
     composite = 'object'
 
@@ -218,42 +264,3 @@ class filed_under(RelationDefinition):
 class require_permission(RelationDefinition):
     subject = ('ExtProject', 'Comment', 'Image', 'File', 'Card', 'TestInstance')
     object = 'CWPermission'
-
-# relation types permissions ##################################################
-
-class license_of(RelationType):
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        'add':    ('managers', RRQLExpression('U has_update_permission O', 'O'),),
-        'delete': ('managers', RRQLExpression('U has_update_permission O', 'O'),),
-        }
-
-class mailinglist_of(RelationType):
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        'add':    ('managers', RRQLExpression('U has_update_permission O', 'O'),),
-        'delete': ('managers', RRQLExpression('U has_update_permission O', 'O'),),
-        }
-
-class documented_by(RelationType):
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        'add':    ('managers', 'staff', sexpr('developer', 'client'),),
-        'delete': ('managers', 'staff', sexpr('developer', 'client'),),
-    }
-
-class screenshot(RelationType):
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        'add':    ('managers', 'staff', sexpr('developer', 'client'),),
-        'delete': ('managers', 'staff', sexpr('developer', 'client'),),
-    }
-
-
-class attachment(RelationType):
-    __permissions__ = {
-        'read':   ('managers', 'users', 'guests'),
-        # also used for Email attachment File
-        'add':    ('managers', 'staff', RRQLExpression('U has_update_permission S', 'S')),
-        'delete': ('managers', 'staff', RRQLExpression('U has_update_permission S', 'S')),
-    }
