@@ -6,7 +6,7 @@ from cubicweb.devtools.testlib import vreg_instrumentize, print_untested_objects
 
 class AutomaticWebTest(AutomaticWebTest):
     no_auto_populate = ('TestInstance',)
-    ignored_relations = ('nosy_list',)
+    ignored_relations = set(('nosy_list',))
 
     def post_populate(self, cursor):
         self.commit()
@@ -14,11 +14,13 @@ class AutomaticWebTest(AutomaticWebTest):
             version.change_state('published')
 
 def setup_module(*args):
-    vreg_instrumentize(AutomaticWebTest)
+    #XXX DOESNT WORK vreg_instrumentize(AutomaticWebTest)
+    pass
 
 def teardown_module(options, results):
-    if not options.exitfirst or not (results.errors or results.failures):
-        print_untested_objects(AutomaticWebTest)
+    #if not options.exitfirst or not (results.errors or results.failures):
+    #    print_untested_objects(AutomaticWebTest)
+    pass
 
 if __name__ == '__main__':
     from logilab.common.testlib import unittest_main
