@@ -1,9 +1,9 @@
 from datetime import timedelta
 
-from cubes.tracker.test.test_multisources import BaseMSTC
-
-class TwoSourcesTC(BaseMSTC):
+from cubes.tracker.testutils import BaseMSTC, ms_test_init
+repo2, cnx2, repo3, cnx3, eids = ms_test_init()
 
+class ThreeSourcesTC(BaseMSTC):
     def test_projects_interested_in(self):
         rset = self.execute('Any P,N WHERE P name N, X interested_in P, X eid %(x)s', {'x': self.session.user.eid}, 'x')
         self.assertEquals(len(rset), 3)
@@ -19,17 +19,27 @@ class TwoSourcesTC(BaseMSTC):
         self.assertEquals(ip1v1.state, 'dev')
 
     def test_nonregr6(self):
-        rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
-                            {'text': 'extern'})
-        self.assertEquals(len(rset), 2)
-        rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
-                            {'text': 'intern'})
-        self.assertEquals(len(rset), 3)
-        rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
-                            {'text': 'project'})
-        # 3 projects in two external sources, 3 projects + 2 tickets in internal source
-        self.assertEquals(len(rset), 8)
-        self.assertEquals(set(sn for s, sn in rset), set(('active development', 'open')))
+        # XXX monkey patch of sqlgenerator needed since sqlite needs distinct
+        # queries for has_text
+        for repo in (self.repo, repo2, repo3):
+            sqlgen = repo.system_source._rql_sqlgen
+            sqlgen.union_sql = sqlgen._SQLGenerator__union_sql
+        try:
+            rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
+                                {'text': 'extern'})
+            self.assertEquals(len(rset), 2)
+            rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
+                                {'text': 'intern'})
+            self.assertEquals(len(rset), 3)
+            rset = self.execute('Any E,F ORDERBY F WHERE X has_text %(text)s, X in_state E, E name F',
+                                {'text': 'project'})
+            # 3 projects in two external sources, 3 projects + 2 tickets in internal source
+            self.assertEquals(len(rset), 8)
+            self.assertEquals(set(sn for s, sn in rset), set(('active development', 'open')))
+        finally:
+            for repo in (self.repo, repo2, repo3):
+                sqlgen = repo.system_source._rql_sqlgen
+                sqlgen.union_sql = sqlgen.has_text_need_distinct_union_sql
 
     def test_nonregr7(self):
         rset = self.execute('Any B,TT,NOW - CD,PR,S,C,V,group_concat(TN) '
